@@ -9,8 +9,8 @@ from skimage import measure
 from imea import measure_2d, measure_3d, tools
 
 
-def shape_measurements_3d(img_3d, threshold, spatial_resolution_xy,
-                          spatial_resolution_z=1.0, dalpha=9,
+def shape_measurements_3d(img_3d, threshold_mm, spatial_resolution_xy,
+                          spatial_resolution_z, dalpha=9,
                           min_object_area=10, n_objects_max=-1):
     """Extract 2D and 3D rotation and translation invariant shape measurements
         from a 3d grayscale image.
@@ -20,16 +20,15 @@ def shape_measurements_3d(img_3d, threshold, spatial_resolution_xy,
     img_3d : numpy.ndarray, type float
         3d image in grayscale representation
         (background is zero, grayvalues represent height).
-    threshold : float
-        Threshold in grayvalues for segmentation of `img_3d`.
+    threshold_mm : float
+        Threshold in millimeters for segmentation of `img_3d`.
         Pixels <= `threshold` are considered as background,
-        pixels > threshold_3d_gv as object (foreground).
+        pixels > `threshold_mm` as object (foreground).
     spatial_resolution_xy : float
         Spatial resolution of `img_3d` in x and y direction in [mm/pixel].
         Assumes image is already calibrated, i.e. dx = dy, see Notes.
-    spatial_resolution_z : float, optional
-        Spatial resolution of `img_3d` in z-direction (height) in [mm/grayvalue], by default 1.
-
+    spatial_resolution_z : float
+        Spatial resolution of `img_3d` in z-direction (height) in [mm/grayvalue].
     dalpha : float, optional
         Angle in degrees by which object is rotated at each iteration,
         (e. g. for statistical length), by default 9.
@@ -61,9 +60,15 @@ def shape_measurements_3d(img_3d, threshold, spatial_resolution_xy,
     assert img_3d.dtype != 'bool',\
         "`img_3d` is a boolean not numeric array.\
          Please use `imea.extract_shape_measurements_2d()` for 2D shape measurements"
+    assert spatial_resolution_xy > 0,\
+        "`spatial_resolution_xy` must be > 0 mm/Pixel."
+    assert spatial_resolution_z > 0,\
+        "`spatial_resolution_z` must be > 0 mm/grayvalue."
+
+    threshold_gv = threshold_mm / spatial_resolution_z
 
     imgs_3d, bws = tools.preprocess.extract_and_preprocess_3d_imgs(img_3d,
-                                                                   threshold,
+                                                                   threshold_gv,
                                                                    min_object_area,
                                                                    n_objects_max)
     df_3d = []
