@@ -462,8 +462,7 @@ def distribution_parameters(distribution):
     min_value = distribution.min()
     median_value = np.median(distribution)
     mean_value = np.mean(distribution)
-    modes, _ = stats.mode(distribution)
-    mode = modes[0]
+    mode, _ = stats.mode(distribution, axis=None, keepdims=False)
     std = np.std(distribution)
 
     return max_value, min_value, median_value, mean_value, mode, std
